@@ -22,7 +22,8 @@
 #include "go-data-simple.h"
 #include "go-data-impl.h"
 #include <goffice/utils/go-format.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/utils/go-locale.h>
+#include <goffice/math/go-math.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
@@ -45,10 +46,8 @@ go_data_scalar_val_finalize (GObject *obj)
 {
 	GODataScalarVal *val = (GODataScalarVal *)obj;
 
-	if (val->str != NULL) {
-		g_free (val->str);
-		val->str = NULL;
-	}
+	g_free (val->str);
+	val->str = NULL;
 
 	(*scalar_val_parent_klass->finalize) (obj);
 }
@@ -131,12 +130,12 @@ go_data_scalar_val_class_init (GObjectClass *gobject_klass)
 
 GSF_CLASS (GODataScalarVal, go_data_scalar_val,
 	   go_data_scalar_val_class_init, NULL,
-	   GO_DATA_SCALAR_TYPE)
+	   GO_TYPE_DATA_SCALAR)
 
 GOData *
 go_data_scalar_val_new (double val)
 {
-	GODataScalarVal *res = g_object_new (GO_DATA_SCALAR_VAL_TYPE, NULL);
+	GODataScalarVal *res = g_object_new (GO_TYPE_DATA_SCALAR_VAL, NULL);
 	res->val = val;
 	return GO_DATA (res);
 }
@@ -242,12 +241,12 @@ go_data_scalar_str_init (GObject *obj)
 
 GSF_CLASS (GODataScalarStr, go_data_scalar_str,
 	   go_data_scalar_str_class_init, go_data_scalar_str_init,
-	   GO_DATA_SCALAR_TYPE)
+	   GO_TYPE_DATA_SCALAR)
 
 GOData *
 go_data_scalar_str_new (char const *str, gboolean needs_free)
 {
-	GODataScalarStr *res = g_object_new (GO_DATA_SCALAR_STR_TYPE, NULL);
+	GODataScalarStr *res = g_object_new (GO_TYPE_DATA_SCALAR_STR, NULL);
 	res->str	= str;
 	res->needs_free = needs_free;
 	return GO_DATA (res);
@@ -368,7 +367,7 @@ go_data_vector_val_as_str (GOData const *dat)
 	if (vec->n ==0)
 		return g_strdup ("");
 
-	sep = format_get_col_sep ();
+	sep = go_locale_get_col_sep ();
 	g_snprintf (sz, sizeof (sz), "%g", vec->val[0]);
 	str = g_string_new (sz);
 	for (i = 1; i < vec->n; i++) {
@@ -403,9 +402,9 @@ go_data_vector_val_from_str (GOData *dat, char const *str)
 		if (*end) {
 			if (!sep) {
 				/* allow the use of all possible seps */
-				if ((sep = format_get_arg_sep ()) != *end)
-					if ((sep = format_get_col_sep ()) != *end)
-						sep = format_get_row_sep ();
+				if ((sep = go_locale_get_arg_sep ()) != *end)
+					if ((sep = go_locale_get_col_sep ()) != *end)
+						sep = go_locale_get_row_sep ();
 			}
 			if (*end != sep) {
 				g_array_free (values, TRUE);
@@ -446,12 +445,12 @@ go_data_vector_val_class_init (GObjectClass *gobject_klass)
 
 GSF_CLASS (GODataVectorVal, go_data_vector_val,
 	   go_data_vector_val_class_init, NULL,
-	   GO_DATA_VECTOR_TYPE)
+	   GO_TYPE_DATA_VECTOR)
 
 GOData *
 go_data_vector_val_new (double *val, unsigned n, GDestroyNotify notify)
 {
-	GODataVectorVal *res = g_object_new (GO_DATA_VECTOR_VAL_TYPE, NULL);
+	GODataVectorVal *res = g_object_new (GO_TYPE_DATA_VECTOR_VAL, NULL);
 	res->val = val;
 	res->n = n;
 	res->notify = notify;
@@ -494,8 +493,7 @@ go_data_vector_str_finalize (GObject *obj)
 	if (str->translate_notify != NULL)
 		(*str->translate_notify) (str->translate_data);
 
-	if (str->base.values != NULL)
-		g_free (str->base.values);
+	g_free (str->base.values);
 	str->base.values = NULL;
 
 	(*vector_str_parent_klass->finalize) (obj);
@@ -536,7 +534,7 @@ go_data_vector_str_as_str (GOData const *dat)
 	char sep;
 	int i;
 
-	sep = format_get_col_sep ();
+	sep = go_locale_get_col_sep ();
 	if (vec->n ==0)
 		return g_strdup ("");
 
@@ -567,13 +565,13 @@ go_data_vector_str_from_str (GOData *dat, char const *str)
 
 	values = g_array_sized_new (FALSE, FALSE, sizeof(char*), 16);
 	/* search which separator has been used */
-	sep = format_get_col_sep ();
+	sep = go_locale_get_col_sep ();
 	end = strchr (cur, sep);
 	if (end == NULL) {
-		sep = format_get_arg_sep ();
+		sep = go_locale_get_arg_sep ();
 		end = strchr (cur, sep);
 		if (end ==NULL)
-			sep = format_get_row_sep ();
+			sep = go_locale_get_row_sep ();
 	}
 	vec->str = NULL;
 	vec->n = 0;
@@ -719,12 +717,12 @@ go_data_vector_str_init (GObject *obj)
 
 GSF_CLASS (GODataVectorStr, go_data_vector_str,
 	   go_data_vector_str_class_init, go_data_vector_str_init,
-	   GO_DATA_VECTOR_TYPE)
+	   GO_TYPE_DATA_VECTOR)
 
 GOData *
 go_data_vector_str_new (char const * const *str, unsigned n, GDestroyNotify notify)
 {
-	GODataVectorStr *res = g_object_new (GO_DATA_VECTOR_STR_TYPE, NULL);
+	GODataVectorStr *res = g_object_new (GO_TYPE_DATA_VECTOR_STR, NULL);
 	res->str = str;
 	res->n	 = n;
 	res->notify = notify;
@@ -733,7 +731,7 @@ go_data_vector_str_new (char const * const *str, unsigned n, GDestroyNotify noti
 
 /**
  * go_data_vector_str_set_translate_func:
- * @vec: a #GODataVectorStr
+ * @vector: a #GODataVectorStr
  * @func: a #GOTranslateFunc
  * @data: data to be passed to @func and @notify
  * @notify: a #GODestroyNotify function to be called when @vec is 
@@ -766,7 +764,7 @@ dgettext_swapped (char const *msgid,
 
 /**
  * go_data_vector_str_set_translation_domain:
- * @action_group: a #GtkActionGroup
+ * @vector: a #GODataVectorStr
  * @domain: the translation domain to use for dgettext() calls
  * 
  * Sets the translation domain and uses dgettext() for translating the 
@@ -867,13 +865,17 @@ go_data_matrix_val_load_values (GODataMatrix *mat)
 static double
 go_data_matrix_val_get_value (GODataMatrix *mat, unsigned i, unsigned j)
 {
-	return mat->values[i * mat->size.columns + j];
+	GODataMatrixVal const *val = (GODataMatrixVal const *)mat;
+
+	return val->val[i * val->size.columns + j];
 }
 
 static char *
 go_data_matrix_val_get_str (GODataMatrix *mat, unsigned i, unsigned j)
 {
-	return g_strdup_printf ("%g", mat->values[i * mat->size.columns + j]);
+	GODataMatrixVal const *val = (GODataMatrixVal const *)mat;
+
+	return g_strdup_printf ("%g", val->val[i * val->size.columns + j]);
 }
 
 static char *
@@ -887,8 +889,8 @@ go_data_matrix_val_as_str (GOData const *dat)
 	if (mat->size.rows == 0 || mat->size.columns == 0)
 		return g_strdup ("");
 
-	col_sep = format_get_col_sep ();
-	row_sep = format_get_row_sep ();
+	col_sep = go_locale_get_col_sep ();
+	row_sep = go_locale_get_row_sep ();
 	g_snprintf (sz, sizeof (sz), "%g", mat->val[0]);
 	str = g_string_new (sz);
 	for (j = 1; j < mat->size.columns; j++) {
@@ -921,8 +923,8 @@ go_data_matrix_val_from_str (GOData *dat, char const *str)
 	g_return_val_if_fail (str != NULL, TRUE);
 
 	values = g_array_sized_new (FALSE, FALSE, sizeof(double), 16);
-	col_sep = format_get_col_sep ();
-	row_sep = format_get_row_sep ();
+	col_sep = go_locale_get_col_sep ();
+	row_sep = go_locale_get_row_sep ();
 	i = j = columns = 0;
 	if (mat->notify && mat->val)
 		(*mat->notify) (mat->val);
@@ -994,12 +996,12 @@ go_data_matrix_val_class_init (GObjectClass *gobject_klass)
 
 GSF_CLASS (GODataMatrixVal, go_data_matrix_val,
 	   go_data_matrix_val_class_init, NULL,
-	   GO_DATA_MATRIX_TYPE)
+	   GO_TYPE_DATA_MATRIX)
 
 GOData *
 go_data_matrix_val_new (double *val, unsigned rows, unsigned columns, GDestroyNotify   notify)
 {
-	GODataMatrixVal *res = g_object_new (GO_DATA_MATRIX_VAL_TYPE, NULL);
+	GODataMatrixVal *res = g_object_new (GO_TYPE_DATA_MATRIX_VAL, NULL);
 	res->val = val;
 	res->size.rows = rows;
 	res->size.columns = columns;
