@@ -29,6 +29,13 @@
 
 G_BEGIN_DECLS
 
+typedef enum {
+	GOG_AXIS_POLAR_UNIT_DEGREES,
+	GOG_AXIS_POLAR_UNIT_RADIANS,
+	GOG_AXIS_POLAR_UNIT_GRADS,
+	GOG_AXIS_POLAR_UNIT_MAX
+} GogAxisPolarUnit;
+
 typedef enum {
 	GOG_AXIS_ELEM_MIN = 0,
 	GOG_AXIS_ELEM_MAX,
@@ -49,6 +56,7 @@ typedef struct _GogAxisMap GogAxisMap;
 GogAxisMap*   gog_axis_map_new	 	  (GogAxis *axis, double offset, double length);
 double	      gog_axis_map 		  (GogAxisMap *map, double value);
 double	      gog_axis_map_to_view	  (GogAxisMap *map, double value);
+double	      gog_axis_map_derivative_to_view (GogAxisMap *map, double value);
 double	      gog_axis_map_from_view	  (GogAxisMap *map, double value);
 gboolean      gog_axis_map_finite	  (GogAxisMap *map, double value);
 double	      gog_axis_map_get_baseline	  (GogAxisMap *map);
@@ -56,12 +64,13 @@ void 	      gog_axis_map_get_extents 	  (GogAxisMap *map, double *start, double
 void	      gog_axis_map_get_bounds 	  (GogAxisMap *map, double *minimum, double *maximum);
 void 	      gog_axis_map_free		  (GogAxisMap *map);
 gboolean      gog_axis_map_is_valid 	  (GogAxisMap *map);
+gboolean      gog_axis_map_is_inverted 	  (GogAxisMap *map);
 
 /*****************************************************************************/
 
-#define GOG_AXIS_TYPE	(gog_axis_get_type ())
-#define GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_AXIS_TYPE, GogAxis))
-#define IS_GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_AXIS_TYPE))
+#define GOG_TYPE_AXIS	(gog_axis_get_type ())
+#define GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_AXIS, GogAxis))
+#define GOG_IS_AXIS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_AXIS))
 
 GType gog_axis_get_type (void);
 
@@ -74,6 +83,8 @@ gboolean      gog_axis_get_bounds 	  (GogAxis const *axis,
 void	      gog_axis_set_bounds 	  (GogAxis *axis,
 					   double minimum, double maximum);
 void 	      gog_axis_set_extents 	  (GogAxis *axis, double start, double stop);
+GOFormat     *gog_axis_get_format	  (GogAxis const *axis);
+gboolean      gog_axis_set_format	  (GogAxis *axis, GOFormat *fmt);
 unsigned      gog_axis_get_ticks 	  (GogAxis *axis, GogAxisTick **ticks);
 GOData	     *gog_axis_get_labels	  (GogAxis const *axis,
 					   GogPlot **plot_that_labeled_axis);
@@ -89,6 +100,11 @@ void	      gog_axis_bound_changed	  (GogAxis *axis, GogObject *contrib);
 
 GogGridLine  *gog_axis_get_grid_line 	  (GogAxis *axis, gboolean major);
 
+void	      		gog_axis_set_polar_unit		(GogAxis *axis, GogAxisPolarUnit unit);
+GogAxisPolarUnit	gog_axis_get_polar_unit		(GogAxis *axis);
+double 			gog_axis_get_polar_perimeter 	(GogAxis *axis);
+double 			gog_axis_get_circular_rotation 	(GogAxis *axis);
+
 G_END_DECLS
 
 #endif /* GOG_AXIS_H */
