@@ -46,23 +46,7 @@
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-pixbuf.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-rect-ellipse.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkviewport.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 typedef struct _GraphGuruState		GraphGuruState;
@@ -189,7 +173,7 @@ graph_typeselect_minor (GraphGuruTypeSelector *typesel, FooCanvasItem *item)
 	gboolean enable_next_button;
 	GogPlot *plot;
 
-	if (typesel->current_minor_item == item)
+	if (typesel->current_minor_item == item || typesel->sample_graph_item == item)
 		return;
 
 	type = g_object_get_data (G_OBJECT (item), PLOT_TYPE_KEY);
@@ -357,7 +341,7 @@ cb_sample_pressed (GraphGuruTypeSelector *typesel)
 	if (typesel->sample_graph_item == NULL) {
 		GtkAllocation *size = &GTK_WIDGET (typesel->canvas)->allocation;
 		typesel->sample_graph_item = foo_canvas_item_new (typesel->graph_group,
-			GOG_CONTROL_FOOCANVAS_TYPE,
+			GOG_TYPE_CONTROL_FOOCANVAS,
 			"model", typesel->state->graph,
 			NULL);
 		cb_typesel_sample_plot_resize (FOO_CANVAS (typesel->canvas),
@@ -615,9 +599,9 @@ cb_attr_tree_selection_change (GraphGuruState *s)
 		/* if we ever go back to the typeselector be sure to 
 		 * add the plot to the last selected chart */
 		s->chart = (GogChart *)
-			gog_object_get_parent_typed (obj, GOG_CHART_TYPE);
+			gog_object_get_parent_typed (obj, GOG_TYPE_CHART);
 		s->plot = (GogPlot *)
-			gog_object_get_parent_typed (obj, GOG_PLOT_TYPE);
+			gog_object_get_parent_typed (obj, GOG_TYPE_PLOT);
 
 		if (s->plot == NULL) {
 			if (s->chart == NULL && s->graph != NULL) {
@@ -752,13 +736,12 @@ populate_graph_item_list (GogObject *obj, GogObject *select, GraphGuruState *s,
 	if (insert) {
 		GogObject *gparent = gog_object_get_parent (obj);
 		gint i = g_slist_index (gparent->children, obj);
-		if (i > 0) {
-			GtkTreeIter sibling;
-			gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (s->prop_model),
-				&sibling, parent, i-1);
-			gtk_tree_store_insert_after (s->prop_model, &iter,
-				parent, &sibling);
-		} else
+		GtkTreeIter sibling;
+		if (i > 0 && gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (s->prop_model),
+													&sibling, parent, i-1))
+				gtk_tree_store_insert_after (s->prop_model, &iter,
+					parent, &sibling);
+		else
 			gtk_tree_store_prepend (s->prop_model, &iter, parent);
 	} else
 		gtk_tree_store_append (s->prop_model, &iter, parent);
@@ -952,7 +935,7 @@ graph_guru_init_format_page (GraphGuruState *s)
 						     "outline_color_rgba", 0x707070ff,	/* grey */
 						     NULL);
 	s->sample_graph_item = foo_canvas_item_new (foo_canvas_root (FOO_CANVAS (canvas)),
-						    GOG_CONTROL_FOOCANVAS_TYPE,
+						    GOG_TYPE_CONTROL_FOOCANVAS,
 						    "model", s->graph,
 						    NULL);
 	gtk_widget_add_events (canvas, GDK_POINTER_MOTION_HINT_MASK);
@@ -1057,7 +1040,7 @@ cb_graph_guru_clicked (GtkWidget *button, GraphGuruState *s)
 			NULL : s->register_closure->data;
 		
 		instance_and_params[0].g_type = 0;
-		g_value_init (&instance_and_params[0], GOG_GRAPH_TYPE);
+		g_value_init (&instance_and_params[0], GOG_TYPE_GRAPH);
 		g_value_set_instance (&instance_and_params[0], s->graph);
 
 		instance_and_params[1].g_type = 0;
@@ -1134,7 +1117,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	GtkWidget *selector;
 	GladeXML *gui;
 
-	gui = go_libglade_new ("gog-guru-type-selector.glade", "type_selector", GETTEXT_PACKAGE, s->cc);
+	gui = go_glade_new ("gog-guru-type-selector.glade", "type_selector", GETTEXT_PACKAGE, s->cc);
 
 	typesel = g_new0 (GraphGuruTypeSelector, 1);
 	typesel->state = s;
@@ -1143,6 +1126,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	typesel->current_type = NULL;
 	typesel->sample_graph_item = NULL;
 	typesel->max_priority_so_far = -1;
+	s->type_selector = typesel;
 
 	selector = glade_xml_get_widget (gui, "type_selector");
 
@@ -1233,7 +1217,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 static gboolean
 graph_guru_init (GraphGuruState *s)
 {
-	s->gui = go_libglade_new ("gog-guru.glade", NULL, GETTEXT_PACKAGE, s->cc);
+	s->gui = go_glade_new ("gog-guru.glade", NULL, GETTEXT_PACKAGE, s->cc);
         if (s->gui == NULL)
                 return TRUE;
 
@@ -1297,21 +1281,21 @@ gog_guru (GogGraph *graph, GogDataAllocator *dalloc,
 	g_closure_ref (closure);
 
 	if (graph != NULL) {
-		g_return_val_if_fail (IS_GOG_GRAPH (graph), NULL);
+		g_return_val_if_fail (GOG_IS_GRAPH (graph), NULL);
 
 		state->graph = gog_graph_dup (graph);
 		state->chart = NULL;
 		state->plot  = NULL;
 	} else {
 		state->plot = NULL;
-		state->graph = g_object_new (GOG_GRAPH_TYPE, NULL);
+		state->graph = g_object_new (GOG_TYPE_GRAPH, NULL);
 		state->chart = GOG_CHART (gog_object_add_by_name (
 				GOG_OBJECT (state->graph), "Chart", NULL));
-		if (IS_GO_DOC_CONTROL (dalloc))
+		if (GO_IS_DOC_CONTROL (dalloc))
 			g_object_set (state->graph,
 						  "document", go_doc_control_get_doc (GO_DOC_CONTROL (dalloc)),
 						  NULL);
-		else if (IS_GO_DOC_CONTROL (cc))
+		else if (GO_IS_DOC_CONTROL (cc))
 			g_object_set (state->graph,
 						  "document", go_doc_control_get_doc (GO_DOC_CONTROL (cc)),
 						  NULL);
@@ -1340,3 +1324,15 @@ gog_guru (GogGraph *graph, GogDataAllocator *dalloc,
 
 	return state->dialog;
 }
+
+void
+gog_guru_add_custom_widget (GtkWidget *guru, GtkWidget *custom)
+{
+	GraphGuruState *state = g_object_get_data (G_OBJECT (guru), "state");
+	GtkBox *box = GTK_BOX (gtk_widget_get_parent (gtk_widget_get_parent (state->type_selector->canvas)));
+	if (custom) {
+		gtk_box_pack_start (GTK_BOX (box), custom, FALSE, TRUE, 0);
+		g_object_set_data (G_OBJECT (custom), "graph", state->graph);
+		gtk_widget_show_all (custom);
+	}
+}
