@@ -35,171 +35,6 @@
 #include <goffice/gtk/goffice-gtk.h>
 #endif
 
-/*****************************************************************************/
-
-/**
- * gog_editor_new:
- *
- * Returns: a new GogEditor object, which is used to store a collection of
- * 	property edition widgets (pages). The returned object must be freed
- * 	using @gog_editor_free.
- **/
-GogEditor *
-gog_editor_new (void)
-{
-	GogEditor *editor = g_new (GogEditor, 1);
-
-	editor->store_page = NULL;
-	editor->pages = NULL;
-	g_datalist_init (&editor->registered_widgets);
-
-	return editor;
-}
-
-/**
- * gog_editor_free:
- * @editor: a #GogEditor
- *
- * Frees a GogEditor object.
- **/
-
-void
-gog_editor_free (GogEditor *editor)
-{
-	g_slist_foreach (editor->pages, (GFunc) g_free, NULL);
-	g_slist_free (editor->pages);
-	g_datalist_clear (&editor->registered_widgets);
-
-	g_free (editor);
-}
-
-/**
- * gog_editor_add_page:
- * @editor: a #GogEditor
- * @widget: property edition widget
- * @label: a label identifying the widget
- *
- * Adds a page to @editor.
- */
-
-void
-gog_editor_add_page (GogEditor *editor, gpointer widget, char const *label)
-{
-	GogEditorPage *page;
-
-	g_return_if_fail (editor != NULL);
-	page = g_new (GogEditorPage, 1);
-
-	page->widget = widget;
-	page->label = label;
-
-	editor->pages = g_slist_prepend (editor->pages, page);
-}
-
-/**
- * gog_editor_set_store_page:
- * @editor: a #GogEditor
- * @store_page: placeholder for the last selected page
- *
- * Sets a placeholder for storing the last active editor page.
- **/
-
-void
-gog_editor_set_store_page (GogEditor *editor, unsigned *store_page)
-{
-	g_return_if_fail (editor != NULL);
-
-	editor->store_page = store_page;
-}
-
-#ifdef GOFFICE_WITH_GTK
-
-/**
- * gog_editor_register_widget:
- * @editor: a #GogEditor
- * @widget: a #GtkWidget
- * 
- * Registers a widget that then can be retrieved later using 
- * @gog_editor_get_registered_widget. The main use of this function is to 
- * provide the ability to extend a page.
- **/
-void
-gog_editor_register_widget (GogEditor *editor, GtkWidget *widget)
-{
-	g_return_if_fail (editor != NULL);
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-
-	g_datalist_set_data (&editor->registered_widgets, gtk_widget_get_name (widget), widget);
-}
-
-/**
- * gog_editor_get_registered_widget:
- * @editor: a #GogEditor
- * @name: the name of the registered widget
- *
- * Returns: a widget previously registered using @gog_editor_register_widget.
- **/
-GtkWidget *
-gog_editor_get_registered_widget (GogEditor *editor, char const *name)
-{
-	g_return_val_if_fail (editor != NULL, NULL);
-
-	return g_datalist_get_data (&editor->registered_widgets, name);
-}
-
-static void
-cb_switch_page (G_GNUC_UNUSED GtkNotebook *n, G_GNUC_UNUSED GtkNotebookPage *p,
-		guint page_num, guint *store_page)
-{
-		*store_page = page_num;
-}
-
-/**
- * gog_editor_get_notebook:
- * @editor: a #GogEditor
- *
- * Returns: a GtkNotebook from the widget collection stored in @editor.
- **/
-GtkWidget *
-gog_editor_get_notebook (GogEditor *editor)
-{
-	GtkWidget *notebook;
-	GogEditorPage *page;
-	GSList *ptr;
-	unsigned page_count = 0;
-
-	notebook = gtk_notebook_new ();
-	if (editor->pages != NULL) {
-		for (ptr = editor->pages; ptr != NULL; ptr = ptr->next) {
-			page = (GogEditorPage *) ptr->data;
-			gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook),
-						   GTK_WIDGET (page->widget),
-						   gtk_label_new (page->label));
-			gtk_widget_show (page->widget);
-			page_count ++;
-		}
-	} else {
-		/* Display a blank page */
-		GtkWidget *label =  gtk_label_new (NULL);
-		gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook),
-					   label, NULL);
-		gtk_widget_show (label);
-		page_count = 1;
-	}
-
-	if (editor->store_page != NULL) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), *editor->store_page);
-		g_signal_connect (G_OBJECT (notebook),
-				  "switch_page",
-				  G_CALLBACK (cb_switch_page), editor->store_page);
-	} else
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
-
-	return notebook;
-}
-
-#endif
-
 typedef struct {
 	char const *label;
 	char const *value;
@@ -287,7 +122,7 @@ gog_object_parent_changed (GogObject *child, gboolean was_set)
 		(*klass->parent_changed) (ptr->data, was_set);
 	}
 
-	if (IS_GOG_DATASET (child))
+	if (GOG_IS_DATASET (child))
 		gog_dataset_parent_changed (GOG_DATASET (child), was_set);
 }
 
@@ -530,7 +365,7 @@ cb_update_editor (GogObject *gobj, ObjectPrefState *state)
 
 static void
 gog_object_populate_editor (GogObject *gobj, 
-			    GogEditor *editor, 
+			    GOEditor *editor, 
 			    G_GNUC_UNUSED GogDataAllocator *dalloc, 
 			    GOCmdContext *cc)
 {
@@ -551,7 +386,7 @@ gog_object_populate_editor (GogObject *gobj,
 	if (!(allowable_positions & (GOG_POSITION_MANUAL | GOG_POSITION_COMPASS)))
 		return;	
 
-	gui = go_libglade_new ("gog-object-prefs.glade", "gog_object_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-object-prefs.glade", "gog_object_prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -692,7 +527,7 @@ gog_object_populate_editor (GogObject *gobj,
 	w = glade_xml_get_widget (gui, "gog_object_prefs");
 	g_object_set_data_full (G_OBJECT (w), "state", state, 
 				(GDestroyNotify) object_pref_state_free);  
-	gog_editor_add_page (editor, w, _("Position"));
+	go_editor_add_page (editor, w, _("Position"));
 }
 #endif
 
@@ -772,6 +607,14 @@ gog_object_class_init (GObjectClass *klass)
 			FALSE, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
+	/**
+	 * GogObject::child-added:
+	 * @object: the object on which the signal is emitted
+	 * @child: The new #GogObject whose parent is @object
+	 *
+	 * The ::child-added signal is emitted AFTER the child has been added
+	 * and AFTER the parent-changed signal has been called for it.
+	 **/
 	gog_object_signals [CHILD_ADDED] = g_signal_new ("child-added",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -779,6 +622,14 @@ gog_object_class_init (GObjectClass *klass)
 		NULL, NULL,
 		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE,	1, G_TYPE_OBJECT);
+	/**
+	 * GogObject::child-removed:
+	 * @object: the object on which the signal is emitted
+	 * @child: The new #GogObject whose parent is @object
+	 *
+	 * The ::child-removed signal is emitted BEFORE the child has been
+	 * added and BEFORE the parent-changed signal has been called for it.
+	 **/
 	gog_object_signals [CHILD_REMOVED] = g_signal_new ("child-removed",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -896,7 +747,7 @@ gog_object_generate_name (GogObject *obj)
 unsigned
 gog_object_get_id (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), 0);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), 0);
 	g_return_val_if_fail (obj != NULL, 0);
 
 	return obj->id;
@@ -931,7 +782,7 @@ gog_object_set_id (GogObject *obj, unsigned id)
 	GSList *ptr;
 	GogObject *child;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	if (id == 0) {
 		gog_object_generate_id (obj);
@@ -1014,7 +865,7 @@ gog_object_dup (GogObject const *src, GogObject *new_parent, GogDataDuplicator d
 		}
 	g_free (props);
 
-	if (IS_GOG_DATASET (src)) {	/* convenience to save data */
+	if (GOG_IS_DATASET (src)) {	/* convenience to save data */
 		if (datadup)
 			datadup (GOG_DATASET (src), GOG_DATASET (dst));
 		else
@@ -1039,7 +890,7 @@ gog_object_dup (GogObject const *src, GogObject *new_parent, GogDataDuplicator d
 GogObject *
 gog_object_get_parent (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 	return obj->parent;
 }
 
@@ -1054,7 +905,7 @@ gog_object_get_parent (GogObject const *obj)
 GogObject *
 gog_object_get_parent_typed (GogObject const *obj, GType t)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	for (; obj != NULL ; obj = obj->parent)
 		if (G_TYPE_CHECK_INSTANCE_TYPE (obj, t))
@@ -1071,10 +922,10 @@ gog_object_get_parent_typed (GogObject const *obj, GType t)
 GogGraph *
 gog_object_get_graph (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	for (; obj != NULL ; obj = obj->parent)
-		if (IS_GOG_GRAPH (obj))
+		if (GOG_IS_GRAPH (obj))
 			return GOG_GRAPH (obj);
 	return NULL;
 }
@@ -1098,7 +949,7 @@ gog_object_get_theme (GogObject const *obj)
 char const *
 gog_object_get_name (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 	return (obj->user_name != NULL && *obj->user_name != '\0') ? obj->user_name : obj->auto_name;
 }
 
@@ -1117,7 +968,7 @@ gog_object_set_name (GogObject *obj, char *name, GError **err)
 {
 	GogObject *tmp;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	if (obj->user_name == name)
 		return;
@@ -1145,7 +996,7 @@ gog_object_get_children (GogObject const *obj, GogObjectRole const *filter)
 {
 	GSList *ptr, *res = NULL;
 
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	if (filter == NULL)
 		return g_slist_copy (obj->children);
@@ -1203,9 +1054,9 @@ gog_object_get_child_by_name (GogObject const *obj, char const *name)
 gboolean
 gog_object_is_deletable (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), FALSE);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), FALSE);
 
-	if (IS_GOG_GRAPH (obj))
+	if (GOG_IS_GRAPH (obj))
 		return FALSE;
 
 	return obj->role == NULL || obj->role->can_remove == NULL ||
@@ -1303,7 +1154,7 @@ gog_object_can_reorder (GogObject const *obj, gboolean *inc_ok, gboolean *dec_ok
 	GogObject const *parent;
 	GSList *ptr;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	if (inc_ok != NULL)
 		*inc_ok = FALSE;
@@ -1351,7 +1202,7 @@ gog_object_reorder (GogObject const *obj, gboolean inc, gboolean goto_max)
 	GogObject *parent, *obj_follows;
 	GSList **ptr, *tmp;
 
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	if (obj->parent == NULL || gog_object_get_graph (obj) == NULL)
 		return NULL;
@@ -1412,12 +1263,12 @@ gog_object_get_editor (GogObject *obj, GogDataAllocator *dalloc,
 {
 #ifdef GOFFICE_WITH_GTK
 	GtkWidget *notebook;
-	GogEditor *editor;
+	GOEditor *editor;
 	GogObjectClass *klass = GOG_OBJECT_GET_CLASS (obj);
 
 	g_return_val_if_fail (klass != NULL, NULL);
 
-	editor = gog_editor_new ();
+	editor = go_editor_new ();
 	if (klass->populate_editor) {
 		/* If there are pending updates do them before creating the editor
 		 * to avoid expensive widget changes later */
@@ -1425,9 +1276,9 @@ gog_object_get_editor (GogObject *obj, GogDataAllocator *dalloc,
 		(*klass->populate_editor) (obj, editor, dalloc, cc);
 	}
 
-	notebook = gog_editor_get_notebook (editor);
+	notebook = go_editor_get_notebook (editor);
 
-	gog_editor_free (editor);
+	go_editor_free (editor);
 
 	return notebook;
 #else
@@ -1515,7 +1366,7 @@ gog_object_emit_changed (GogObject *obj, gboolean resize)
 	if (gog_klass->use_parent_as_proxy) {
 		obj = obj->parent;
 		if (obj != NULL) {
-			g_return_if_fail (IS_GOG_OBJECT (obj));
+			g_return_if_fail (GOG_IS_OBJECT (obj));
 			gog_object_emit_changed (obj, resize);
 		}
 		return;
@@ -1685,7 +1536,7 @@ GogObject *
 gog_object_add_by_name (GogObject *parent,
 			char const *role, GogObject *child)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (parent), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (parent), NULL);
 	return gog_object_add_by_role (parent,
 		gog_object_find_role_by_name (parent, role), child);
 }
@@ -1715,7 +1566,7 @@ gog_object_set_invisible (GogObject *obj, gboolean invisible)
 GogObjectPosition
 gog_object_get_position_flags (GogObject const *obj, GogObjectPosition mask)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), GOG_POSITION_SPECIAL & mask);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), GOG_POSITION_SPECIAL & mask);
 	return obj->position & mask;
 }
 
@@ -1732,7 +1583,7 @@ gog_object_get_position_flags (GogObject const *obj, GogObjectPosition mask)
 gboolean
 gog_object_set_position_flags (GogObject *obj, GogObjectPosition flags, GogObjectPosition mask)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), FALSE);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), FALSE);
 
 	if (obj->role == NULL)
 		return FALSE;
