@@ -24,25 +24,18 @@
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-plot-impl.h>
 #include <goffice/graph/gog-theme.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-error-bar.h>
 #include <goffice/data/go-data.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhseparator.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkcombobox.h>
 #endif
 
 #include <string.h>
@@ -89,8 +82,8 @@ static void
 gog_series_element_set_index (GogSeriesElement *gse, int ind)
 {
 	gse->index = ind;
-	gog_styled_object_apply_theme (&gse->base, gse->base.style);
-	gog_styled_object_style_changed (&gse->base);
+	go_styled_object_apply_theme (GO_STYLED_OBJECT (gse), gse->base.style);
+	go_styled_object_style_changed (GO_STYLED_OBJECT (gse));
 }
 
 static void
@@ -154,7 +147,7 @@ cb_index_changed (GtkSpinButton *spin_button, GogSeriesElement *element)
 
 static void
 gog_series_element_populate_editor (GogObject *gobj,
-				    GogEditor *editor,
+				    GOEditor *editor,
 			   GogDataAllocator *dalloc,
 			   GOCmdContext *cc)
 {
@@ -187,21 +180,21 @@ gog_series_element_populate_editor (GogObject *gobj,
 	gtk_widget_show_all (vbox);
 
 	if (gse_vbox == NULL)
-		gog_editor_add_page (editor, vbox, _("Settings"));
+		go_editor_add_page (editor, vbox, _("Settings"));
 
-	gog_editor_set_store_page (editor, &series_element_pref_page);
+	go_editor_set_store_page (editor, &series_element_pref_page);
 }
 #endif
 
 static void
-gog_series_element_init_style (GogStyledObject *gso, GogStyle *style)
+gog_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = GOG_SERIES (GOG_OBJECT (gso)->parent);
-	GogStyle *parent_style;
+	GOStyle *parent_style;
 
 	g_return_if_fail (series != NULL);
 
-	parent_style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+	parent_style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 	style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, FALSE);
@@ -235,7 +228,7 @@ gog_series_element_class_init (GogSeriesElementClass *klass)
 
 GSF_CLASS (GogSeriesElement, gog_series_element,
 	   gog_series_element_class_init, NULL /*gog_series_element_init*/,
-	   GOG_STYLED_OBJECT_TYPE)
+	   GOG_TYPE_STYLED_OBJECT)
 
 /*****************************************************************************/
 
@@ -265,6 +258,7 @@ enum {
 	SERIES_PROP_0,
 	SERIES_PROP_HAS_LEGEND,
 	SERIES_PROP_INTERPOLATION,
+	SERIES_PROP_INTERPOLATION_SKIP_INVALID,
 	SERIES_PROP_FILL_TYPE
 };
 
@@ -285,7 +279,7 @@ role_series_element_allocate (GogObject *series)
 	GogObject *gse;
 
 	if (type == 0)
-		type = GOG_SERIES_ELEMENT_TYPE;
+		type = GOG_TYPE_SERIES_ELEMENT;
 
 	gse = g_object_new (type, NULL);
 	if (gse != NULL)
@@ -298,8 +292,8 @@ static void
 role_series_element_post_add (GogObject *parent, GogObject *child)
 {
 	GogSeries *series = GOG_SERIES (parent);
-	gog_styled_object_set_style (GOG_STYLED_OBJECT (child),
-		gog_styled_object_get_style (GOG_STYLED_OBJECT (parent)));
+	go_styled_object_set_style (GO_STYLED_OBJECT (child),
+		go_styled_object_get_style (GO_STYLED_OBJECT (parent)));
 	series->overrides = g_list_insert_sorted (series->overrides, child,
 		(GCompareFunc) element_compare);
 }
@@ -348,6 +342,9 @@ gog_series_set_property (GObject *obj, guint param_id,
 	case SERIES_PROP_INTERPOLATION:
 		series->interpolation = go_line_interpolation_from_str (g_value_get_string (value));
 		break;
+	case SERIES_PROP_INTERPOLATION_SKIP_INVALID:
+		series->interpolation_skip_invalid = g_value_get_boolean (value);
+		break;
 	case SERIES_PROP_FILL_TYPE:
 		name = g_value_get_string (value);
 		for (i = 0; i < G_N_ELEMENTS (_fill_type_infos); i++)
@@ -375,6 +372,9 @@ gog_series_get_property (GObject *obj, guint param_id,
 	case SERIES_PROP_INTERPOLATION:
 		g_value_set_string (value, go_line_interpolation_as_str (series->interpolation));
 		break;
+	case SERIES_PROP_INTERPOLATION_SKIP_INVALID:
+		g_value_set_boolean (value, series->interpolation_skip_invalid);
+		break;
 	case SERIES_PROP_FILL_TYPE:
 		g_value_set_string (value, _fill_type_infos[series->fill_type].name);
 		break;
@@ -417,7 +417,25 @@ cb_show_in_legend (GtkToggleButton *b, GObject *series)
 static void
 cb_line_interpolation_changed (GtkComboBox *box, GogSeries *series)
 {
+	GladeXML *gui = g_object_get_data (G_OBJECT (box), "gui");
+	GtkWidget *widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "skip-button"));
+	GtkWidget *table = glade_xml_get_widget (gui, "clamps-table");
 	series->interpolation = gtk_combo_box_get_active (box);
+	gtk_widget_set_sensitive (widget, !go_line_interpolation_auto_skip (series->interpolation));
+	widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "fill-type"));
+	if (series->interpolation == GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
+		gtk_widget_show (table);
+	else
+		gtk_widget_hide (table);
+	if (widget)
+		gtk_widget_set_sensitive (widget, !go_line_interpolation_auto_skip (series->interpolation));
+	gog_object_emit_changed (GOG_OBJECT (series), FALSE);
+}
+
+static void
+cb_line_interpolation_skip_changed (GtkToggleButton *btn, GogSeries *series)
+{
+	series->interpolation_skip_invalid = gtk_toggle_button_get_active (btn);
 	gog_object_emit_changed (GOG_OBJECT (series), FALSE);
 }
 
@@ -430,7 +448,7 @@ cb_fill_type_changed (GtkComboBox *combo, GObject *obj)
 
 static void
 gog_series_populate_editor (GogObject *gobj,
-			    GogEditor *editor,
+			    GOEditor *editor,
 		   GogDataAllocator *dalloc,
 		   GOCmdContext *cc)
 {
@@ -444,6 +462,7 @@ gog_series_populate_editor (GogObject *gobj,
 	GogDataset *set = GOG_DATASET (gobj);
 	GogSeriesDesc const *desc;
 	GogDataType data_type;
+	GtkComboBox *combo = NULL;
 
 	g_return_if_fail (series->plot != NULL);
 
@@ -504,39 +523,79 @@ gog_series_populate_editor (GogObject *gobj,
 		0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 	gtk_widget_show_all (GTK_WIDGET (table));
 
-	gog_editor_add_page (editor, GTK_WIDGET (table), _("Data"));
+	go_editor_add_page (editor, GTK_WIDGET (table), _("Data"));
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
-	box = gog_editor_get_registered_widget (editor, "line_box");
+	box = go_editor_get_registered_widget (editor, "line_box");
 	if (series_class->has_interpolation && box != NULL) {
 		GladeXML *gui;
 		GtkWidget *widget;
 
-		gui = go_libglade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_glade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
+			int i;
+			GogAxisSet set = gog_plot_axis_set_pref (gog_series_get_plot (series));
+			GogDataset *clamp_set = gog_series_get_interpolation_params (series);
 			widget = glade_xml_get_widget (gui, "interpolation_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
-			widget = glade_xml_get_widget (gui, "interpolation_combo");
-			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), series->interpolation);
-			g_signal_connect (widget, "changed",
+			widget = glade_xml_get_widget (gui, "interpolation-table");
+			/* create an interpolation type combo and populate it */
+			combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
+			if (set & 1 << GOG_AXIS_RADIAL)
+				for (i = 0; i < GO_LINE_INTERPOLATION_MAX; i++) {
+					if (go_line_interpolation_supports_radial (i))
+						gtk_combo_box_append_text (combo, _(go_line_interpolation_as_label (i)));
+				}
+			else
+				for (i = 0; i < GO_LINE_INTERPOLATION_MAX; i++)
+					gtk_combo_box_append_text (combo, _(go_line_interpolation_as_label (i)));
+			gtk_combo_box_set_active (combo, series->interpolation);
+			g_signal_connect (combo, "changed",
 					  G_CALLBACK (cb_line_interpolation_changed), series);
-			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
+			gtk_table_attach (GTK_TABLE (widget), GTK_WIDGET (combo), 1, 2,
+					  0, 1, (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+					  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), 0, 0);
+			gtk_widget_show_all (widget);
+			widget = glade_xml_get_widget (gui, "interpolation-skip-invalid");
+			g_object_set_data (G_OBJECT (combo), "skip-button", widget); 
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), series->interpolation_skip_invalid);
+			if (go_line_interpolation_auto_skip (series->interpolation))
+				gtk_widget_set_sensitive (widget, FALSE);
+			g_signal_connect (widget, "toggled",
+					  G_CALLBACK (cb_line_interpolation_skip_changed), series);
+			if (clamp_set) {
+				GtkWidget *w;
+				widget = glade_xml_get_widget (gui, "clamps-table");
+				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 0, GOG_DATA_SCALAR));
+				gtk_widget_show (w);
+				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 1, GOG_DATA_SCALAR));
+				gtk_widget_show (w);
+				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+				if (series->interpolation != GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
+					gtk_widget_hide (widget);
+			}
+			g_object_set_data_full (G_OBJECT (combo), "gui", gui,
 						(GDestroyNotify) g_object_unref);
 		}
 	}
 
-	box = gog_editor_get_registered_widget (editor, "fill_extension_box");
+	box = go_editor_get_registered_widget (editor, "fill_extension_box");
 	if (series_class->has_fill_type && box != NULL) {
 		GladeXML *gui;
 		GtkWidget *widget;
 
-		gui = go_libglade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_glade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			widget = glade_xml_get_widget (gui, "fill_type_combo");
 			gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
 			g_signal_connect (G_OBJECT (widget), "changed",
 					  G_CALLBACK (cb_fill_type_changed), series);
+			if (combo)
+				g_object_set_data (G_OBJECT (combo), "fill-type", widget);
+			if (series->interpolation == GO_LINE_INTERPOLATION_CLOSED_SPLINE)
+				gtk_widget_set_sensitive (widget, FALSE);
 			widget = glade_xml_get_widget (gui, "fill_type_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, TRUE, TRUE, 0);
 			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
@@ -544,7 +603,7 @@ gog_series_populate_editor (GogObject *gobj,
 		}
 	}
 
-	gog_editor_set_store_page (editor, &series_pref_page);
+	go_editor_set_store_page (editor, &series_pref_page);
 }
 #endif
 
@@ -556,7 +615,7 @@ gog_series_update (GogObject *obj)
 }
 
 static void
-gog_series_init_style (GogStyledObject *gso, GogStyle *style)
+gog_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = (GogSeries const *)gso;
 	style->interesting_fields = series->plot->desc.series.style_fields;
@@ -625,6 +684,12 @@ gog_series_class_init (GogSeriesClass *klass)
 			_("Type of line interpolation"),
 			"linear",
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION_SKIP_INVALID,
+		g_param_spec_boolean ("interpolation-skip-invalid", 
+			_("Interpolation skip invalid"),
+			_("Should the series interpolation ignore the invalid data"),
+			FALSE,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_FILL_TYPE,
 		g_param_spec_string ("fill-type", 
 			_("Fill type"),
@@ -682,14 +747,13 @@ gog_series_dataset_set_dim (GogDataset *set, int dim_i,
 	GogSeries *series = GOG_SERIES (set);
 	GogGraph *graph = gog_object_get_graph (GOG_OBJECT (series));
 
-	g_return_if_fail (IS_GOG_PLOT (series->plot));
+	g_return_if_fail (GOG_IS_PLOT (series->plot));
 	g_return_if_fail (dim_i >= -1);
 
 	if (dim_i < 0) {
 		char *name = NULL;
 		if (NULL != series->values[-1].data)
-			name = g_strdup (go_data_scalar_get_str (
-				GO_DATA_SCALAR (series->values[-1].data)));
+			name = go_data_get_scalar_string (series->values[-1].data);
 		gog_object_set_name (GOG_OBJECT (series), name, err);
 		return;
 	}
@@ -740,9 +804,9 @@ gog_series_dataset_dim_changed (GogDataset *set, int dim_i)
 		gog_object_request_update (GOG_OBJECT (set));
 	} else {
 		GOData *name_src = series->values[-1].data;
-		char const *name = (name_src != NULL)
-			? go_data_scalar_get_str (GO_DATA_SCALAR (name_src)) : NULL;
-		gog_object_set_name (GOG_OBJECT (set), g_strdup (name), NULL);
+		char *name = (name_src != NULL)
+			? go_data_get_scalar_string (name_src) : NULL;
+		gog_object_set_name (GOG_OBJECT (set), name, NULL);
 	}
 }
 
@@ -757,8 +821,8 @@ gog_series_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogSeries, gog_series,
 		NULL, NULL, gog_series_class_init, NULL,
-		gog_series_init, GOG_STYLED_OBJECT_TYPE, 0,
-		GSF_INTERFACE (gog_series_dataset_init, GOG_DATASET_TYPE))
+		gog_series_init, GOG_TYPE_STYLED_OBJECT, 0,
+		GSF_INTERFACE (gog_series_dataset_init, GOG_TYPE_DATASET))
 
 /**
  * gog_series_get_plot :
@@ -769,7 +833,7 @@ GSF_CLASS_FULL (GogSeries, gog_series,
 GogPlot *
 gog_series_get_plot (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 	return series->plot;
 }
 
@@ -782,7 +846,7 @@ gog_series_get_plot (GogSeries const *series)
 gboolean
 gog_series_is_valid (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), FALSE);
+	g_return_val_if_fail (GOG_IS_SERIES (series), FALSE);
 	return series->is_valid;
 }
 
@@ -800,8 +864,8 @@ gog_series_check_validity (GogSeries *series)
 	unsigned i;
 	GogSeriesDesc const *desc;
 
-	g_return_if_fail (IS_GOG_SERIES (series));
-	g_return_if_fail (IS_GOG_PLOT (series->plot));
+	g_return_if_fail (GOG_IS_SERIES (series));
+	g_return_if_fail (GOG_IS_PLOT (series->plot));
 
 	desc = &series->plot->desc.series;
 	for (i = series->plot->desc.series.num_dim; i-- > 0; )
@@ -822,7 +886,7 @@ gog_series_check_validity (GogSeries *series)
 gboolean
 gog_series_has_legend (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), FALSE);
+	g_return_val_if_fail (GOG_IS_SERIES (series), FALSE);
 	return series->has_legend;
 }
 
@@ -841,7 +905,7 @@ gog_series_has_legend (GogSeries const *series)
 void
 gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 {
-	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (GOG_IS_SERIES (series));
 
 	if (ind < 0) {
 		if (series->manual_index && series->plot != NULL)
@@ -856,8 +920,8 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 		return;
 
 	series->index = ind;
-	gog_styled_object_apply_theme (&series->base, series->base.style);
-	gog_styled_object_style_changed (GOG_STYLED_OBJECT (series));
+	go_styled_object_apply_theme (GO_STYLED_OBJECT (series), series->base.style);
+	go_styled_object_style_changed (GO_STYLED_OBJECT (series));
 }
 
 /**
@@ -869,11 +933,12 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
  *
  * return value: a #GODataScalar, without added reference.
  **/
-GODataScalar *
+GOData *
 gog_series_get_name (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
-	return GO_DATA_SCALAR (series->values[-1].data);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
+
+	return series->values[-1].data;
 }
 
 /**
@@ -930,7 +995,7 @@ gog_series_get_valid_element_index (GogSeries const *series, int old_index, int
 	int index;
 	GList *ptr;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), -1);
+	g_return_val_if_fail (GOG_IS_SERIES (series), -1);
 
 	if ((desired_index >= (int) series->num_elements) ||
 	    (desired_index < 0))
@@ -966,7 +1031,7 @@ gog_series_get_element (GogSeries const *series, int index)
 	GList *ptr;
 	GogSeriesElement *element;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 
 	for (ptr = series->overrides; ptr != NULL; ptr = ptr->next) {
 		element = GOG_SERIES_ELEMENT (ptr->data);
@@ -980,7 +1045,7 @@ gog_series_get_element (GogSeries const *series, int index)
 static unsigned int
 gog_series_get_data (GogSeries const *series, int *indices, double **data, int n_vectors)
 {
-	GODataVector *vector;
+	GOData *vector;
 	int i, n_points = 0, vector_n_points;
 	int first, last;
 	int index;
@@ -994,9 +1059,9 @@ gog_series_get_data (GogSeries const *series, int *indices, double **data, int n
 	for (i = 0; i < n_vectors; i++) {
 		index = indices != NULL ? indices[i] : i;
 		if (index >= first && index <= last &&
-		    (vector = GO_DATA_VECTOR (series->values[index].data)) != NULL) {
-			data[i] = go_data_vector_get_values (vector);
-			vector_n_points = go_data_vector_get_len (vector);
+		    (vector = series->values[index].data) != NULL) {
+			data[i] = go_data_get_values (vector);
+			vector_n_points = go_data_get_vector_size (vector);
 			if (!is_set) {
 				is_set = TRUE;
 				n_points = vector_n_points;
@@ -1063,7 +1128,7 @@ gog_series_get_xyz_data (GogSeries const  *series,
 GogSeriesFillType
 gog_series_get_fill_type (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	g_return_val_if_fail (GOG_IS_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
 
 	return series->fill_type;
 }
@@ -1073,7 +1138,7 @@ gog_series_set_fill_type (GogSeries *series, GogSeriesFillType fill_type)
 {
 	GogSeriesClass *series_klass;
 
-	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (GOG_IS_SERIES (series));
 	if (series->fill_type == fill_type)
 		return;
 	g_return_if_fail (fill_type >= 0 && fill_type < GOG_SERIES_FILL_TYPE_INVALID);
@@ -1093,7 +1158,7 @@ gog_series_populate_fill_type_combo (GogSeries const *series, GtkComboBox *combo
 	GogSeriesFillType fill_type;
 	unsigned int i;
 
-	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (GOG_IS_SERIES (series));
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	g_return_if_fail (series_klass->valid_fill_type_list != NULL);
 
@@ -1113,10 +1178,22 @@ gog_series_get_fill_type_from_combo (GogSeries const *series, GtkComboBox *combo
 {
 	GogSeriesClass *series_klass;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	g_return_val_if_fail (GOG_IS_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	g_return_val_if_fail (series_klass->valid_fill_type_list != NULL, GOG_SERIES_FILL_TYPE_INVALID);
 
 	return series_klass->valid_fill_type_list[gtk_combo_box_get_active (combo)];
 }
 #endif
+
+GogDataset *
+gog_series_get_interpolation_params (GogSeries const *series)
+{
+	GogSeriesClass *series_klass;
+
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
+	series_klass = GOG_SERIES_GET_CLASS (series);
+	return (series_klass->get_interpolation_params)?
+			series_klass->get_interpolation_params (series):
+			NULL;
+}
