@@ -1,5 +1,5 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * go-format-sel.c: A widget to select a format
  *
  * Copyright (C) 2006-2007 Morten Welinder (terra@gnome.org)
@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- **/
+ */
 
 #include <goffice/goffice-config.h>
 #include "go-format-sel.h"
@@ -520,18 +520,28 @@ static void
 fmt_dialog_init_fmt_list (GOFormatSel *gfs, char const *const *formats,
 			  GtkTreeIter *select)
 {
-	GtkTreeIter iter;
-	char *fmt;
-	const char *cur_fmt = go_format_as_XL (gfs->format.spec);
+	GOFormatMagic cur_magic = go_format_get_magic (gfs->format.spec);
 
 	for (; *formats; formats++) {
+		GtkTreeIter iter;
+		char *fmt = go_format_str_localize (*formats);
+		GOFormat *f = go_format_new_from_XL (*formats);
+		GOFormatMagic magic = go_format_get_magic (f);
+		gboolean found;
+
 		gtk_list_store_append (gfs->format.formats.model, &iter);
-		fmt = go_format_str_localize (*formats);
 		gtk_list_store_set (gfs->format.formats.model, &iter,
 				    0, fmt, -1);
 		g_free (fmt);
 
-		if (!strcmp (*formats, cur_fmt))
+		/* Magic formats are fully defined by their magic.  */
+		found = cur_magic
+			? (cur_magic == magic)
+			: go_format_eq (f, gfs->format.spec);
+
+		go_format_unref (f);
+
+		if (found)
 			*select = iter;
 	}
 }
@@ -855,6 +865,8 @@ cb_format_entry_changed (GtkEditable *w, GOFormatSel *gfs)
 		return;
 
 	fmt = go_format_str_delocalize (gtk_entry_get_text (GTK_ENTRY (w)));
+	if (!fmt)
+		fmt = g_strdup ("*");
 	cur_fmt = go_format_as_XL (gfs->format.spec);
 
 	if (strcmp (cur_fmt, fmt)) {
@@ -1152,7 +1164,7 @@ set_format_category_menu_from_style (GOFormatSel *gfs)
 {
 	GOFormatFamily page;
 
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 
 	/* Attempt to extract general parameters from the current format */
 	page = study_format (gfs);
@@ -1242,7 +1254,7 @@ nfs_init (GOFormatSel *gfs)
 
 	GtkWidget *tmp;
 	GtkTreeViewColumn *column;
-	GoComboText *combo;
+	GOComboText *combo;
 	char const *name;
 	int i;
 	GOFormatFamily page;
@@ -1254,7 +1266,7 @@ nfs_init (GOFormatSel *gfs)
 	gfs->show_format_with_markup = FALSE;
 	gfs->locale = NULL;
 
-	gfs->gui = go_libglade_new ("go-format-sel.glade", NULL, GETTEXT_PACKAGE, NULL);
+	gfs->gui = go_glade_new ("go-format-sel.glade", NULL, GETTEXT_PACKAGE, NULL);
 	if (gfs->gui == NULL)
 		return;
 
@@ -1495,7 +1507,7 @@ go_format_sel_new_full (gboolean use_markup)
 {
 	GOFormatSel *gfs;
 
-	gfs = g_object_new (GO_FORMAT_SEL_TYPE, NULL);
+	gfs = g_object_new (GO_TYPE_FORMAT_SEL, NULL);
 
 	if (gfs != NULL)
 		gfs->show_format_with_markup = use_markup;
@@ -1522,7 +1534,7 @@ go_format_sel_new (void)
 void
 go_format_sel_set_focus (GOFormatSel *gfs)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 
 	gtk_widget_grab_focus (GTK_WIDGET (gfs->format.menu));
 }
@@ -1531,9 +1543,9 @@ void
 go_format_sel_set_style_format (GOFormatSel *gfs,
 				GOFormat *style_format)
 {
-	GoComboText *combo;
+	GOComboText *combo;
 
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	g_return_if_fail (style_format != NULL);
 
 	go_format_ref (style_format);
@@ -1558,7 +1570,7 @@ void
 go_format_sel_set_dateconv (GOFormatSel *gfs,
 			    GODateConventions const *date_conv)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	g_return_if_fail (date_conv != NULL);
 
 	/* FIXME is it safe ? */
@@ -1571,21 +1583,21 @@ go_format_sel_set_dateconv (GOFormatSel *gfs,
 GOFormat *
 go_format_sel_get_fmt (GOFormatSel *gfs)
 {
-	g_return_val_if_fail (IS_GO_FORMAT_SEL (gfs), NULL);
+	g_return_val_if_fail (GO_IS_FORMAT_SEL (gfs), NULL);
 	return gfs->format.spec;
 }
 
 GODateConventions const *
 go_format_sel_get_dateconv (GOFormatSel *gfs)
 {
-	g_return_val_if_fail (IS_GO_FORMAT_SEL (gfs), NULL);
+	g_return_val_if_fail (GO_IS_FORMAT_SEL (gfs), NULL);
 	return gfs->date_conv;
 }
 
 void
 go_format_sel_show_preview (GOFormatSel *gfs)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	gtk_widget_show (gfs->format.preview_box);
 	draw_format_preview (gfs, TRUE);
 }
@@ -1593,7 +1605,7 @@ go_format_sel_show_preview (GOFormatSel *gfs)
 void
 go_format_sel_hide_preview (GOFormatSel *gfs)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	gtk_widget_hide (gfs->format.preview_box);
 }
 
@@ -1601,7 +1613,7 @@ void
 go_format_sel_editable_enters (GOFormatSel *gfs,
 			       GtkWindow *window)
 {
-	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
+	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
 	go_gtk_editable_enters (window, gfs->format.widget[F_DECIMAL_SPIN]);
 	go_gtk_editable_enters (window, gfs->format.widget[F_ENTRY]);
 }
