@@ -103,8 +103,10 @@ go_gtk_dialog_add_button (GtkDialog *dialog, char const* text, char const* stock
 
 /**
  * go_glade_new :
- * @gcc : #GOCmdContext
  * @gladefile : the name of the file load
+ * @root :
+ * @domain :
+ * @gcc : #GOCmdContext
  *
  * Simple utility to open glade files
  *
@@ -142,7 +144,7 @@ go_glade_new (char const *gladefile, char const *root,
  * @gui : #GladeXML
  * @instance_name : widget name
  * @detailed_signal : signal name
- * @c_handle : #GCallback
+ * @c_handler : #GCallback
  * @data : arbitrary
  *
  * Convenience wrapper around g_signal_connect for glade.
@@ -164,11 +166,11 @@ go_glade_signal_connect	(GladeXML	*gui,
 }
 
 /**
- * go_glade_signal_connect :
+ * go_glade_signal_connect_swapped :
  * @gui : #GladeXML
  * @instance_name : widget name
  * @detailed_signal : signal name
- * @c_handle : #GCallback
+ * @c_handler : #GCallback
  * @data : arbitary
  *
  * Convenience wrapper around g_signal_connect_swapped for glade.
@@ -189,6 +191,49 @@ go_glade_signal_connect_swapped (GladeXML	*gui,
 	return g_signal_connect_swapped (w, detailed_signal, c_handler, data);
 }
 
+/**
+ * go_xml_builder_new :
+ * @uifile : the name of the file load
+ * @domain :
+ * @gcc : #GOCmdContext
+ *
+ * Simple utility to open ui files
+ *
+ * Returns: a new #GtkBuilder or NULL
+ **/
+GtkBuilder *
+go_xml_builder_new (char const *uifile,
+		    char const *domain, GOCmdContext *gcc)
+{
+	GtkBuilder *gui;
+	char *f;
+	GError *error = NULL;
+
+	g_return_val_if_fail (uifile != NULL, NULL);
+
+	if (!g_path_is_absolute (uifile))
+		f = g_build_filename (go_sys_data_dir (), "glade", uifile, NULL);
+	else
+		f = g_strdup (uifile);
+
+	gui = gtk_builder_new ();
+	gtk_builder_set_translation_domain (gui, domain);
+	gtk_builder_add_from_file (gui, f, &error);
+	if (gui == NULL && gcc != NULL) {
+		char *msg;
+		if (error) {
+			msg = g_strdup (error->message);
+			g_error_free (error);
+		} else
+			msg = g_strdup_printf (_("Unable to open file '%s'"), f);
+		go_cmd_context_error_system (gcc, msg);
+		g_free (msg);
+	}
+	g_free (f);
+
+	return gui;
+}
+
 /*
  * A variant of gtk_window_activate_default that does not end up reactivating
  * the widget that [Enter] was pressed in.
@@ -614,7 +659,7 @@ cb_format_combo_changed (GtkComboBox *combo, GtkWidget *expander)
  **/
 char *
 go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
-			 GOImageFormat *ret_format, double *resolution)
+			    GOImageFormat *ret_format, double *resolution)
 {
 	GOImageFormat format;
 	GOImageFormatInfo const *format_info;
@@ -642,7 +687,7 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 
 	g_object_set (G_OBJECT (fsel), "title", _("Save as"), NULL);
 
-	gui = go_libglade_new ("go-image-save-dialog-extra.glade", 
+	gui = go_glade_new ("go-image-save-dialog-extra.glade", 
 			       "image_save_dialog_extra", 
 			       GETTEXT_PACKAGE, NULL);
 	if (gui != NULL) {
